@@ -3,6 +3,7 @@ import argparse
 import multiprocessing
 import sys
 from io import StringIO
+import os
 
 import numpy as np
 from tqdm import tqdm
@@ -52,7 +53,8 @@ def parse_args(args=None):
         '--symptomatic-r0',
         nargs='+',
         help='''Production number of symptomatic infectors, should be specified as a single
-            fixed number, or a range. Multipliers are allowed to specify symptomatic r0 for
+            fixed number, or 2.5%% and 97.5%% quantile of a normal distribution from which individual
+            production number will be drawn. Multipliers are allowed to specify symptomatic r0 for
             each group. This parameter reflects the infectivity of virus carrier measured
             by the average number of individuals one infected individual "would" infect if
             infectivity is not blocked by for example quarantine and susceptibility of
@@ -62,18 +64,18 @@ def parse_args(args=None):
         '--asymptomatic-r0',
         nargs='+',
         help='''Production number of asymptomatic infectors, should be specified as a single
-            fixed number or a range. Multipliers are allowed to specify asymptomatic r0 for
+            fixed number or or 2.5%% and 97.5%% quantile of a normal distribution from which individual
+            production number will be drawn. Multipliers are allowed to specify asymptomatic r0 for
             each group.''')
     parser.add_argument(
         '--symptomatic-transmissibility-model',
         nargs='+',
         help='''Model used for asymptomatic cases with parameters. The default model
             normal has a duration of 8 days after incubation, and a peak happens at 2/3 of
-            incubation. The piece wise model has a proportion for the start of infection
-            (relative to incubation period), a proportion for the peak of infectivity (
-            relative to incubation period), and a range of days after the
-            onset of symptoms. The models should be specified as "normal" (no parameter is
-            allowed), or model name with parameters such as "piecewise 0.1 0.3 7 9".
+            incubation. An alternative piece wise model has a stage of no infectivity, a stage
+            for increasing and a stage for decreasing infectivity. The proportion of stages
+            and time after incubation period are controlled by a lognormal distribution.
+            Parameters to this model could be specified but not recommended.
         '''
     )
     parser.add_argument(
@@ -81,11 +83,10 @@ def parse_args(args=None):
         nargs='+',
         help='''Model used for asymptomatic cases with parameters. The default model
             normal has a duration of 12 and peaks at 4.8 day. The piecewise model has
-            a proportion for the start of infection,  a proportion for the peak of
-            infectivity, and a range of days after the infection (no incubation period
-            when compared to the symptomatic case). The models should be specified as "normal"
-            (no parameter is allowed), or model name with parameters such as
-            "piecewise 0.1 0.3 5 7".
+            a stage of no infectivity, a stage for increasing and a stage for decreasing
+            infectivity. The proportion of stages and the overall duration are controlled
+            by a lognormal distribution. Parameters to this model could be specified but
+            not recommended.
         '''
     )
 
@@ -161,6 +162,11 @@ def parse_args(args=None):
         type=int,
         help='Number of process to use for simulation. Default to number of CPU cores.'
     )
+    parser.add_argument(
+        '--summary-report',
+        help='''Generate a summary report and write to the specified file,
+          which can be "-" for standard output.'''
+    )
     return parser.parse_args(args)
 
 class FilteredStringIO(StringIO):
@@ -250,6 +256,25 @@ def main(argv=None):
                 f'Option --stop-if currently only supports t>TIME to stop after certain time point.'
             )
 
+
+
+    completed_ids = set()
+    append_mode = os.path.isfile(args.logfile)
+    if append_mode:
+        with open(args.logfile, 'r') as lf:
+            for line in lf:
+                try:
+                    id = int(line.split('\t', 1)[0])
+                    if id <= args.repeats:
+                        completed_ids.add(id)
+                except:
+                    # might be $ or "id"
+                    pass
+
+    if len(completed_ids) == args.repeats:
+        print(f'All simulations have been performed. Remove {args.logfile} if you would like to rerun.')
+        return 0
+
     workers = [
         Worker(tasks, results, args, cmd=argv if argv else sys.argv[1:])
         for i in range(min(args.jobs, args.repeats))
@@ -257,20 +282,29 @@ def main(argv=None):
     for worker in workers:
         worker.start()
 
-    with open(args.logfile, 'w') as logger:
-        logger.write('id\ttime\tevent\ttarget\tparams\n')
+    submitted = 0
+    with open(args.logfile, 'a' if append_mode else 'w') as logger:
+        if not append_mode:
+            logger.write('id\ttime\tevent\ttarget\tparams\n')
         for i in range(args.repeats):
-            tasks.put(i + 1)
+            if i+1 not in completed_ids:
+                submitted += 1
+                tasks.put(i + 1)
         for i in range(args.jobs):
             tasks.put(None)
         #
-        for i in tqdm(range(args.repeats)):
+        for i in tqdm(range(len(completed_ids), args.repeats),
+            total=args.repeats, initial=len(completed_ids)):
             result = results.get()
             logger.write(result)
             if 'ERROR' in result:
                 break
 
-    summarize_simulations(args.logfile)
+    for worker in workers:
+        # wait for workers to complete
+        worker.join()
+
+    summarize_simulations(args.logfile, args.summary_report)
     return 0
 
 
