@@ -1,6 +1,5 @@
 from datetime import datetime
 import subprocess
-import sys
 
 from collections import defaultdict
 from importlib import import_module
@@ -8,7 +7,7 @@ from itertools import groupby
 
 from .event import Event, EventType
 from .model import Model
-from .population import Individual, Population
+from .population import Population
 
 
 def load_plugins(args, simulator=None):
@@ -44,7 +43,8 @@ def load_plugins(args, simulator=None):
         #
         if not hasattr(obj, 'apply'):
             raise ValueError('No "apply" function is defined for plugin')
-        plugins.append([obj, args])
+        if not args.disable:
+            plugins.append([obj, args])
     return plugins
 
 
@@ -82,34 +82,8 @@ class Simulator(object):
         self.model.draw_prop_asym_carriers()
 
         # collection of individuals
-        population = Population(
-            popsize=self.simu_args.popsize,
-            uneven_susceptibility=self.simu_args.susceptibility is not None)
-        idx = 0
-
-        for ps in self.simu_args.popsize:
-            if '=' in ps:
-                # this is named population size
-                name, sz = ps.split('=', 1)
-            else:
-                name = ''
-                sz = ps
-            try:
-                sz = int(sz)
-            except Exception:
-                raise ValueError(
-                    f'Named population size should be name=int: {ps} provided')
-
-            population.add([
-                Individual(
-                    name + str(idx),
-                    group=name,
-                    susceptibility=getattr(self.model.params,
-                                           f'susceptibility_multiplier_{name}',
-                                           1),
-                    model=self.model,
-                    logger=self.logger) for idx in range(idx, idx + sz)
-            ])
+        population = Population(popsize=self.simu_args.popsize, model=self.model,
+            vicinity=self.simu_args.vicinity, logger=self.logger)
 
         events = defaultdict(list)
         self.logger.id = id
@@ -201,14 +175,32 @@ class Simulator(object):
             # if self.simu_args.handle_symptomatic and all(
             #         x.infected for x in population.values()):
             #     break
+        remaining_events = defaultdict(int)
+        infected_by = set()
+        for time, events_at_time in events.items():
+            for event in events_at_time:
+                if event.action.name in ('SHOW_SYMPTOM', 'RECOVER', 'REMOVAL') and event.target not in population:
+                    continue
+                if event.action.name in ('INFECTION'):
+                    if event.kwargs['by'] in population:
+                        infected_by.add(event.kwargs['by'])
+                    else:
+                        continue
+                remaining_events[event.action.name] += 1
+        if infected_by:
+            remaining_events['INFECTION'] = f"{remaining_events['INFECTION']} (by {len(infected_by)} infectors)"
+        remaining_events = ','.join(f'{x}:{y}' for x,y in remaining_events.items())
         res = {
             'popsize': len(population),
             'prop_asym': f'{self.model.params.prop_asym_carriers:.3f}',
             'time': datetime.now().strftime("%m/%d/%Y-%H:%M:%S"),
         }
+        if remaining_events:
+            res['remaining_events'] = remaining_events
         if self.simu_args.stop_if:
             res['stop_if'] = ''.join(self.simu_args.stop_if)
         params = ','.join([f'{x}={y}' for x, y in res.items()])
+
         self.logger.write(
             f'{self.logger.id}\t{time:.2f}\t{EventType.END.name}\t{len(population)}\t{params}\n'
         )
